---
meta:
  id: uvsqsat
  endian: be
doc: |
  : UVSQsat telemtry description file 
  : Version 0.0.2 
  :
  : 
  :
  :field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
  :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
  :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
  :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
  :field ctl: ax25_frame.ax25_header.ctl
  :field pid: ax25_frame.payload.pid
  

seq:
  - id: ax25_frame
    type: ax25_frame
    doc-ref: 'https://www.tapr.org/pub_ax25.html'

types:
  ax25_frame:
    seq:
      - id: ax25_header
        type: ax25_header
      - id: payload
        type:
          switch-on: ax25_header.ctl & 0x13
          cases:
            0x03: ui_frame
            0x13: ui_frame
            0x00: i_frame
            0x02: i_frame
            0x10: i_frame
            0x12: i_frame
            _: i_frame
            # 0x11: s_frame

  ax25_header:
    seq:
      - id: dest_callsign_raw
        type: callsign_raw
      - id: dest_ssid_raw
        type: ssid_mask
      - id: src_callsign_raw
        type: callsign_raw
      - id: src_ssid_raw
        type: ssid_mask
      - id: ctl
        type: u1

  callsign_raw:
    seq:
      - id: callsign_ror
        process: ror(1)
        size: 6
        type: callsign

  callsign:
    seq:
      - id: callsign
        type: str
        encoding: ASCII
        size: 6

  ssid_mask:
    seq:
      - id: ssid_mask
        type: u1
    instances:
      ssid:
        value: (ssid_mask & 0x0f) >> 1

  i_frame:
    seq:
      - id: pid
        type: u1
      - id: ax25_info
        size-eos: true

  ui_frame:
    seq:
      - id: pid
        type: u1
      - id: packet_primary_header
        type: packet_primary_header
      - id: packet_secondary_header
        type: packet_secondary_header
      - id: tlm
        type:
          switch-on: packet_secondary_header.sid
          cases:
            0x0E: amsat_ascii
            0x0F: beacon
            0x10: ants_hk
            0x11: obc_status
            0x12: obc_hk_tm
            0x13: mainboard_all_science
            0x14: mainboard_hk
            0x15: ieps_hk_status_tm
            0x16: trxvurx_hk
            0x17: imtq_hk_tm 
            0x18: trxvutx_hk_tm
            _: msg_or_unknow
            
      - id: ax25_info
        size-eos: true
# for command status and other message not recognised  
  msg_or_unknow:
    seq:
      - id: data
        size-eos: true
        
# CCDS - primary packet header 
  packet_primary_header:
    seq:
      - id: packet_version_number
        type: b3
      - id: packet_id_packet_type
        type: b1
      - id: packet_id_secondary_header_flag
        type: b1
      - id: packet_id_application_process_id
        type: b11 
      - id: packet_sequence_control_secquence_flag
        type: b2
      - id: packet_sequence_control_count_or_name
        type: b14
      - id: packet_data_length
        type: u2
        
# CCDS - secondary  packet header 
  packet_secondary_header:
    seq:
      - id:  tm_packet_pus_version_number
        type: b4
      - id: spacecraft_time_reference_status
        type: b4
      - id: service_type_id
        type: u1
      - id: message_subtype_id
        type: u1
      - id: message_type_counter
        type: u2
      - id: destination_id
        type: u2
      - id: time
        type: u4
      - id: toto # to verify 
        type: u2
      - id: toto2 # to verify 
        type: u1
      - id: sid # used to identify the frame type
        type: u1

  ants_hk:
    seq:
      - id: side_a_ants_temperature
        type: u2
      - id: side_a_ants_deployment_status
        type: u2
      - id: side_a_ants_uptime
        type: u4
      - id: side_a_deployment_count_antenna_1
        type: u1
      - id: side_a_deployment_count_antenna_2
        type: u1
      - id: side_a_deployment_count_antenna_3
        type: u1
      - id: side_a_deployment_count_antenna_4
        type: u1
      - id: side_a_deployment_time_antenna_1
        type: u2
      - id: side_a_deployment_time_antenna_2
        type: u2
      - id: side_a_deployment_time_antenna_3
        type: u2
      - id: side_a_deployment_time_antenna_4
        type: u2
      - id: side_b_ants_temperature
        type: u2
      - id: side_b_ants_deployment_status
        type: u2
      - id: side_b_ants_uptime
        type: u2
      - id: side_b_deployment_count_antenna_1
        type: u1
      - id: side_b_deployment_count_antenna_2
        type: u1
      - id: side_b_deployment_count_antenna_3
        type: u1
      - id: side_b_deployment_count_antenna_4
        type: u1
      - id: side_b_deployment_time_antenna_1
        type: u2
      - id: side_b_deployment_time_antenna_2
        type: u2
      - id: side_b_deployment_time_antenna_3
        type: u2
      - id: side_b_deployment_time_antenna_4
        type: u2
  
  mainboard_all_science:
    seq:
      - id: mainboard_science_time
        type: u4
      - id: teachwear_on
        type: u1
      - id: frequence_of_acquisitions
        type: u2
      - id: gainain
        type: u4
      - id: number_of_acquisition_per_science_for_e_r_s
        type: u2
      - id: number_of_acquisition_per_science_for_u_v_s
        type: u2
      - id: fee_plus_x_ers1_signal
        type: u4
      - id: fee_plus_x_ers1_temperature
        type: u4
      - id: fee_plus_x_ers2_signal
        type: u4
      - id: fee_plus_x_ers2_temperature
        type: u4
      - id: fee_plus_x_ers3_signal
        type: u4
      - id: fee_plus_x_ers3_temperature
        type: u4
      - id: fee_plus_x_uvs_signal
        type: u4
      - id: fee_minus_x_ers1_signal
        type: u4
      - id: fee_minus_x_ers1_temperature
        type: u4
      - id: fee_minus_x_ers2_signal
        type: u4
      - id: fee_minus_x_ers2_temperature
        type: u4
      - id: fee_minus_x_ers3_signal
        type: u4
      - id: fee_minus_x_ers3_temperature
        type: u4
      - id: fee_minus_x_uvs_signal
        type: u4
      - id: fee_plus_y_ers1_signal
        type: u4
      - id: fee_plus_y_ers1_temperature
        type: u4
      - id: fee_plus_y_ers2_signal
        type: u4
      - id: fee_plus_y_ers2_temperature
        type: u4
      - id: fee_plus_y_ers3_signal
        type: u4
      - id: fee_plus_y_ers3_temperature
        type: u4
      - id: fee_plus_y_uvs_signal
        type: u4
      - id: fee_minus_y_ers1_signal
        type: u4
      - id: fee_minus_y_ers1_temperature
        type: u4
      - id: fee_minus_y_ers2_signal
        type: u4
      - id: fee_minus_y_ers2_temperature
        type: u4
      - id: fee_minus_y_ers3_signal
        type: u4
      - id: fee_minus_y_ers3_temperature
        type: u4
      - id: fee_minus_y_uvs_signal
        type: u4
      - id: teachwear_acc_x
        type: u2
      - id: teachwear_acc_y
        type: u2
      - id: teachwear_acc_z
        type: u2
      - id: teachwear_deg_c
        type: u2
      - id: teachwear_gyro_x
        type: u2
      - id: teachwear_gyro_y
        type: u2
      - id: teachwear_gyro_z
        type: u2
      - id: teachwear_magn_x
        type: u2
      - id: teachwear_magn_y
        type: u2
      - id: teachwear_magn_z
        type: u2
      - id: teachwear_state
        type: u1
      - id: teachwear_reset_reason
        type: u1
      - id: teachwear_c_r_c
        type: u2     
      
  amsat_ascii:
    seq:
      - id: dummy
        type: u1
        
  mainboard_hk:
    seq:
      - id: mainboard_h_k_time
        type: u4
      - id: h_k_plus_5_v
        type: u2
      - id: h_k_minus_5_v
        type: u2
      - id: h_k_minus_polar
        type: u2
      - id: h_k_temp_a_d_c
        type: u2
      - id: h_k_fee_plus_x_vref
        type: u2
      - id: h_k_fee_minus_x_vref
        type: u2
      - id: h_k_fee_plus_y_vref
        type: u2
      - id: h_k_fee_minus_y_vref
        type: u2


  trxvurx_hk:
    seq:
      - id: instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: supply_voltage
        type: b12
      - id: total_supply_current
        type: b12
      - id: transmitter_current
        type: b12
      - id: receiver_current
        type: b12
      - id: power_amplifier_current
        type: b12
      - id: power_amplifier_temperature
        type: b12
      - id: local_oscillator_temperature
        type: b12
      - id: zero__padding
        type: b4
      - id: trxvu_rx_uptime
        type: u4
# référence table 7.5.1 TRXVU interface control document
    instances:
        instantaneous_received_signal_doppler_hz:
          value: (instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        instantaneous_received_signal_strength_d_bm:
          value: instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        supply_voltage_v:
          value: supply_voltage*0.00488
        total_supply_current_m_a:
          value: total_supply_current*0.16643964
        transmitter_current_m_a:
          value: transmitter_current*0.16643964
        receiver_current_m_a:
          value: receiver_current*0.16643964
        power_amplifier_current_m_a:
          value: power_amplifier_current*0.16643964
        power_amplifier_temperature_c:
          value: (power_amplifier_temperature)*-0.07669+195.6037
        local_oscillator_temperature_c:
          value: (local_oscillator_temperature)*-0.07669+195.6037          
          
  obc_hk_tm:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_enable_status
        type: u4
      - id: supervisor_uptime
        type: u4
      - id: iobc_reset_count
        type: u4
      - id: iobc_measure_temperature
        type: u2
      - id: iobc_measure3v3in
        type: u2
      - id: iobc_measure3v3
        type: u2
      - id: iobc_measure2v_reference
        type: u2
      - id: iobc_measure1v8
        type: u2
      - id: iobc_measure1v0
        type: u2
      - id: iobc_measure_current3v3
        type: u2
      - id: iobc_measure_current1v8
        type: u2
      - id: iobc_measure_current1v0
        type: u2
      - id: iobc_measure_volt_rtc
        type: u2
      - id: iobc_adc_update_flag
        type: u1
      - id: iobc_crc8
        type: u1
      - id: photodiode1
        type: u2
      - id: photodiode2
        type: u2
      - id: photodiode3
        type: u2
      - id: photodiode4
        type: u2
      - id: photodiode5
        type: u2
      - id: photodiode6
        type: u2
      - id: panel_temperature1
        type: u4
      - id: panel_temperature2
        type: u4
      - id: panel_temperature3
        type: u4
      - id: panel_temperature4
        type: u4
      - id: panel_temperature5
        type: u4
      - id: panel_temperature6
        type: u4
    
  ieps_hk_status_tm:
      seq:
      - id: h_k_stid 
        type: u1
      - id: h_k_ivid 
        type: u1
      - id: h_k_rc 
        type: u1
      - id: h_k_bid 
        type: u1
      - id: h_k_cmderr 
        type: b4
      - id: h_k_stat 
        type: b4
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: vip_dist_inputraw
        size: 6
      - id: vip_batt_inputraw
        size: 6
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp2raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: vip_obc00
        size: 6
      - id: vip_obc01
        size: 6
      - id: vip_obc02
        size: 6
      - id: vip_obc03
        size: 6
      - id: vip_obc05
        size: 6
      - id: vip_obc06
        size: 6
      - id: cc1
        size: 8
      - id: cc2
        size: 8
      - id: cc3
        size: 8
      - id: status_stid 
        type: u1
      - id: status_ivid 
        type: u1
      - id: status_rc 
        type: u1
      - id: status_bid 
        type: u1
      - id: status_cmderr 
        type: b4
      - id: status_stat 
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2
        
  obc_status:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_index_of_subsystem
        type: u1
      - id: supervisor_major_version
        type: u1
      - id: supervisor_minor_version
        type: u1
      - id: supervisor_patch_version
        type: u1
      - id: supervisor_git_head_version
        type: u4
      - id: supervisor_serial_number
        type: u2
      - id: compilation_information
        size: 19
      - id: clock_speed
        type: u1
      - id: code_type
        type: u1
      - id: crc_8
        type: u1
      - id: sw_mmode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reserved 
        type: u1
      - id: nb_reset
        type: u1
      - id: reserved2 
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: sdcard_status
        type: u1
      - id: sdcard_last_error
        type: u4
      - id: old_time_t_m_in_sdcard
        type: b56
      - id: new_time_t_m_in_sdcard
        type: b56
        
  trxvutx_hk_tm:
    seq:
      - id: instantaneous_rf_reflected_power_from_transmitter_port
        type : b12
      - id: instantaneous_rf_forward_power_from_transmitter_port
        type : b12
      - id: supply_voltage
        type : b12
      - id: total_supply_current
        type : b12
      - id: transmitter_current
        type : b12
      - id: receiver_current
        type : b12
      - id: power_amplifier_current
        type : b12
      - id: power_amplifier_temperature
        type : b12 
      - id: local_oscillator_temperature
        type : b12
      - id: zero_padding
        type: b4 
      - id: trxvu_tx_uptime
        type: u4
      - id: trxvu_tx_state
        type: u1 
    instances:
        instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: instantaneous_rf_reflected_power_from_transmitter_port * instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: instantaneous_rf_forward_power_from_transmitter_port * instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        supply_voltage_v:
          value: 0.00488 * supply_voltage   
        total_supply_current_ma: 
          value: 0.16643964 * total_supply_current 
        transmitter_current_ma:
          value: transmitter_current * 0.16643964
        receiver_current_ma:
          value: receiver_current * 0.16643964
        power_amplifier_current_ma:
          value: power_amplifier_current * 0.16643964
        power_amplifier_temperature_t:
          value: power_amplifier_temperature * -0.07669 + 195.6037
        local_oscillator_temperature_t:
          value: local_oscillator_temperature * -0.07669 + 195.6037
  imtq_hk_tm:
    seq:
      - id: digitale_voltage
        type: u2  
      - id: analog_voltage
        type: u2   
      - id: digital_current
        type: u2  
      - id: analog_current
        type: u2  
      - id: measure_coil_x_current
        type: u2  
      - id: measure_coil_y_current
        type: u2  
      - id: measure_coil_z_current
        type: u2  
      - id: measure_coil_x_temperature
        type: u2  
      - id: measure_coil_y_temperature
        type: u2  
      - id: measure_coil_z_temperature
        type: u2  
      - id: mcu_temperature
        type: u2  
      - id: i_m_t_q_system_state_mode
        type: u1 
      - id: i_m_t_q_system_state_error
        type: u1  
      - id: i_m_t_q_system_state_configuration
        type: u1
      - id: i_m_t_q_system_state_uptime
        type: u4
 
    instances:
        digitale_voltage_v:
          value: 2 *  (2.5/4095) * digitale_voltage   
        analog_voltage_v: 
          value: 2 *  (2.5/4095) * analog_voltage
        measure_coil_x_current_a:
          value:   (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_a:
          value:   (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_a:
          value:   (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_t:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_t:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_t:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_t:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 /0.00225
  beacon:
    seq:
      - id: sw_mode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reset_order
        type: u1
      - id: nb_reset
        type: u1
      - id: format_sdcard_order
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_tc_ping_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: instantaneous_r_f_reflected_power_from_transmitter_port
        type: b12
      - id: instantaneous_r_f_forward_power_from_transmitter_port
        type: b12
      - id: supply_voltage
        type: b12
      - id: total_supply_current
        type: b12
      - id: transmitter_current
        type: b12
      - id: receiver_current
        type: b12
      - id: power_amplifier_current
        type: b12
      - id: power_amplifier_temperature
        type: b12
      - id: local_oscillator_temperature
        type: b12
      - id: instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvu_supply_voltage
        type: b12
      - id: trxvu_total_supply_current
        type: b12
      - id: trxvu_transmitter_current
        type: b12
      - id: trxvu_receiver_current
        type: b12
      - id: trxvu_power_amplifier_current
        type: b12
      - id: trxvu_power_amplifier_temperature
        type: b12
      - id: trxvu_local_oscillator_temperature
        type: b12
      - id: i_m_t_q_system_state_mode
        type: u1
      - id: measure_coil_x_current
        type: u2
      - id: measure_coil_y_current
        type: u2
      - id: measure_coil_z_current
        type: u2
      - id: measure_coil_x_temperature
        type: u2
      - id: measure_coil_y_temperature
        type: u2
      - id: measure_coil_z_temperature
        type: u2
      - id: m_c_u_temperature
        type: u2
      - id: s_i_d_e_a_ants_temperature
        type: u2
      - id: s_i_d_e_a_ants_deployment_status
        type: u2
      - id: v_o_l_t__b_r_d_s_u_praw
        type: u2
      - id: t_e_m_p_raw
        type: u2
      - id: v_i_p__d_i_s_t__i_n_p_u_traw
        size: 6
      - id: v_i_p__b_a_t_t__i_n_p_u_traw
        size: 6
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: b_a_t__t_e_m_p2_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_o_b_c00
        type: u2
      - id: i__o_b_c00
        type:  u2
      - id: p__o_b_c00
        type:  u2
      - id: v_o_b_c01
        type: u2
      - id: i__o_b_c01
        type:  u2
      - id: p__o_b_c01
        type:  u2
      - id: v_o_b_c02
        type: u2
      - id: i__o_b_c02
        type:  u2
      - id: p__o_b_c02
        type:  u2
      - id: v_o_b_c03
        type: u2
      - id: i__o_b_c03
        type:  u2
      - id: p__o_b_c03
        type:  u2
      - id: v_o_b_c05
        type: u2
      - id: i__o_b_c05
        type:  u2
      - id: p__o_b_c05
        type:  u2
      - id: v_o_b_c06
        type: u2
      - id: i__o_b_c06
        type:  u2
      - id: p__o_b_c06
        type:  u2
      - id: status_stid
        type: u1
      - id: status_ivid
        type: u1
      - id: status_rc
        type: u1
      - id: status_bid
        type: u1
      - id: status_cmderr
        type: b4
      - id: status_stat
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2     
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2      
      - id: photodiode1
        type: u2
      - id: photodiode2
        type: u2
      - id: photodiode3
        type: u2
      - id: photodiode4
        type: u2
      - id: photodiode5
        type: u2
      - id: photodiode6
        type: u2
      - id: panel_temperature1
        type: u4
      - id: panel_temperature2
        type: u4
      - id: panel_temperature3
        type: u4
      - id: panel_temperature4
        type: u4
      - id: panel_temperature5
        type: u4
      - id: panel_temperature6
        type: u4    

    instances: 
        measure_coil_x_current_a:
          value:   (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_a:
          value:   (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_a:
          value:   (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_t:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_t:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_t:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        supply_voltage_v:
          value: 0.00488 * supply_voltage
        supply_voltage_v:
          value: 0.00488 * supply_voltage   
        total_supply_current_ma: 
          value: 0.16643964 * total_supply_current 
        transmitter_current_ma:
          value: transmitter_current * 0.16643964
        receiver_current_ma:
          value: receiver_current * 0.16643964
        power_amplifier_current_ma:
          value: power_amplifier_current * 0.16643964
        power_amplifier_temperature_t:
          value: power_amplifier_temperature * -0.07669 + 195.6037
        local_oscillator_temperature_t:
          value: local_oscillator_temperature * -0.07669 + 195.6037
        instantaneous_received_signal_doppler_hz:
          value: (instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        instantaneous_received_signal_strength_d_bm:
          value: instantaneous_received_signal_strength_at_the_receiver_port*0.03-152




  
       
